==> jc-1.4.0.tar.gz: java/awt/event/FocusAdapter.h <==
// public abstract class java.awt.event.FocusAdapter

// class file dependencies
// @dep_class 85d029885a60bde1 java_awt_event_FocusAdapter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_FocusAdapter_H_
#define _JC_java_awt_event_FocusAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_FocusEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_FocusAdapter$sub_refs	_jc_java_awt_event_FocusAdapter$sub_refs;
typedef struct _jc_java_awt_event_FocusAdapter$sub_nonrefs	_jc_java_awt_event_FocusAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_FocusAdapter$refs	_jc_java_awt_event_FocusAdapter$refs;
typedef struct _jc_java_awt_event_FocusAdapter$nonrefs	_jc_java_awt_event_FocusAdapter$nonrefs;
typedef struct _jc_java_awt_event_FocusAdapter$object	_jc_java_awt_event_FocusAdapter$object;

typedef const struct _jc_java_awt_event_FocusAdapter$vmethods	_jc_java_awt_event_FocusAdapter$vmethods;
typedef const struct _jc_java_awt_event_FocusAdapter$vtable	_jc_java_awt_event_FocusAdapter$vtable;
typedef const struct _jc_java_awt_event_FocusAdapter$vtype	_jc_java_awt_event_FocusAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_FocusAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_FocusAdapter$object *);

// Virtual methods
extern void _jc_java_awt_event_FocusAdapter$method$focusGained$2b0b3146a729e224(_jc_env *, struct _jc_java_awt_event_FocusAdapter$object *, struct _jc_java_awt_event_FocusEvent$object *);
extern void _jc_java_awt_event_FocusAdapter$method$focusLost$b4af7a719a65818b(_jc_env *, struct _jc_java_awt_event_FocusAdapter$object *, struct _jc_java_awt_event_FocusEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_FocusAdapter$method_info$focusGained$2b0b3146a729e224;
extern _jc_method _jc_java_awt_event_FocusAdapter$method_info$focusLost$b4af7a719a65818b;

// Virtual methods structure
struct _jc_java_awt_event_FocusAdapter$vmethods {
	void	(*focusGained$2b0b3146a729e224)(_jc_env *, struct _jc_java_awt_event_FocusAdapter$object *, struct _jc_java_awt_event_FocusEvent$object *);
	void	(*focusLost$b4af7a719a65818b)(_jc_env *, struct _jc_java_awt_event_FocusAdapter$object *, struct _jc_java_awt_event_FocusEvent$object *);
};

// Vtable
struct _jc_java_awt_event_FocusAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_FocusAdapter$vmethods	java_awt_event_FocusAdapter;
};

// Vtype
struct _jc_java_awt_event_FocusAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_FocusAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_FocusAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_FocusAdapter$refs {
    _jc_java_awt_event_FocusAdapter$sub_refs	java_awt_event_FocusAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_FocusAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_FocusAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_FocusAdapter$sub_nonrefs	java_awt_event_FocusAdapter;
};

// Object instance structure
struct _jc_java_awt_event_FocusAdapter$object {
	_jc_java_awt_event_FocusAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_FocusAdapter$vtype	*vtype;
	_jc_java_awt_event_FocusAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_FocusAdapter$vtype _jc_java_awt_event_FocusAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_FocusAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_FocusAdapter$class_object;

#endif	/* _JC_java_awt_event_FocusAdapter_H_ */

==> jc-1.4.6.tar.gz: java/awt/event/FocusAdapter.h <==
// public abstract class java.awt.event.FocusAdapter

// class file dependencies
// @dep_class 85d029885a60bde1 java_awt_event_FocusAdapter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_event_FocusAdapter_H_
#define _JC_java_awt_event_FocusAdapter_H_

// Forward structure declarations
struct _jc_java_awt_event_FocusEvent$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_event_FocusAdapter$sub_refs	_jc_java_awt_event_FocusAdapter$sub_refs;
typedef struct _jc_java_awt_event_FocusAdapter$sub_nonrefs	_jc_java_awt_event_FocusAdapter$sub_nonrefs;
typedef struct _jc_java_awt_event_FocusAdapter$refs	_jc_java_awt_event_FocusAdapter$refs;
typedef struct _jc_java_awt_event_FocusAdapter$nonrefs	_jc_java_awt_event_FocusAdapter$nonrefs;
typedef struct _jc_java_awt_event_FocusAdapter$object	_jc_java_awt_event_FocusAdapter$object;

typedef const struct _jc_java_awt_event_FocusAdapter$vmethods	_jc_java_awt_event_FocusAdapter$vmethods;
typedef const struct _jc_java_awt_event_FocusAdapter$vtable	_jc_java_awt_event_FocusAdapter$vtable;
typedef const struct _jc_java_awt_event_FocusAdapter$vtype	_jc_java_awt_event_FocusAdapter$vtype;

// Constructors
extern void _jc_java_awt_event_FocusAdapter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_awt_event_FocusAdapter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_event_FocusAdapter$method$focusGained$2b0b3146a729e224(_jc_env *, struct _jc_java_awt_event_FocusAdapter$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_event_FocusAdapter$method$focusLost$b4af7a719a65818b(_jc_env *, struct _jc_java_awt_event_FocusAdapter$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_event_FocusAdapter$method_info$focusGained$2b0b3146a729e224;
extern _jc_method _jc_java_awt_event_FocusAdapter$method_info$focusLost$b4af7a719a65818b;

// Virtual methods structure
struct _jc_java_awt_event_FocusAdapter$vmethods {
	void	(*focusGained$2b0b3146a729e224)(_jc_env *, struct _jc_java_awt_event_FocusAdapter$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
	void	(*focusLost$b4af7a719a65818b)(_jc_env *, struct _jc_java_awt_event_FocusAdapter$object *, struct _jc_java_awt_event_FocusEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_event_FocusAdapter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_event_FocusAdapter$vmethods	java_awt_event_FocusAdapter;
};

// Vtype
struct _jc_java_awt_event_FocusAdapter$vtype {
	_jc_type			type;
	_jc_java_awt_event_FocusAdapter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_event_FocusAdapter$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_event_FocusAdapter$refs {
    _jc_java_awt_event_FocusAdapter$sub_refs	java_awt_event_FocusAdapter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_event_FocusAdapter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_event_FocusAdapter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_event_FocusAdapter$sub_nonrefs	java_awt_event_FocusAdapter;
};

// Object instance structure
struct _jc_java_awt_event_FocusAdapter$object {
	_jc_java_awt_event_FocusAdapter$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_event_FocusAdapter$vtype	*vtype;
	_jc_java_awt_event_FocusAdapter$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_event_FocusAdapter$vtype _jc_java_awt_event_FocusAdapter$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_event_FocusAdapter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_event_FocusAdapter$class_object;

#endif	/* _JC_java_awt_event_FocusAdapter_H_ */
